# Generated by Django 3.2.16 on 2023-02-20 10:29

from django.db import migrations, models
import lunes_cms.cms.models.static
import lunes_cms.cms.validators


class Migration(migrations.Migration):
    dependencies = [
        ("cms", "0008_add_numerals_adverbs_and_pronouns_as_word_types"),
    ]

    operations = [
        migrations.CreateModel(
            name="Sponsor",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=255, verbose_name="name")),
                (
                    "logo",
                    models.ImageField(
                        blank=True,
                        upload_to=lunes_cms.cms.models.static.upload_sponsor_logos,
                        validators=[
                            lunes_cms.cms.validators.validate_multiple_extensions
                        ],
                        verbose_name="logo",
                    ),
                ),
            ],
            options={
                "verbose_name": "sponsor",
                "verbose_name_plural": "sponsors",
            },
        ),
    ]
