# Generated by Django 3.2.16 on 2023-02-20 20:14

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cms", "0007_document_created_by_link"),
    ]

    operations = [
        migrations.AlterField(
            model_name="document",
            name="word_type",
            field=models.CharField(
                choices=[
                    ("Nomen", "Substantiv"),
                    ("Verb", "Verb"),
                    ("Adjektiv", "Adjektiv"),
                    ("Numeral", "Numeral"),
                    ("Pronomen", "Pronomen"),
                    ("Adverb", "Adverb"),
                ],
                default="",
                max_length=255,
                verbose_name="word type",
            ),
        ),
    ]
